@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::StatementResult;
 # ABSTRACT: Result of running a Cypher statement (a stream of records)
-$Neo4j::Driver::StatementResult::VERSION = '0.14';
+$Neo4j::Driver::StatementResult::VERSION = '0.15';
 
 use Carp qw(croak);
 
@@ -133,7 +133,14 @@ sub _fetch_next {
 	if ( $self->{stream} ) {
 		my @row = $self->{stream}->fetch_next;
 		$record = { row => \@row } if @row;
-		croak 'fetch_next Bolt error: client ' . $self->{stream}->client_errnum . ' ' . $self->{stream}->client_errmsg . '; server ' . $self->{stream}->server_errcode . ' ' . $self->{stream}->server_errmsg if $self->{stream}->failure && $self->{stream}->failure != -1;
+		
+		unless ($self->{stream}->success) {
+			# success() == -1 is not an error condition; it simply
+			# means that there are no more records on the stream
+			my $stream = $self->{stream};
+			croak sprintf "Bolt error %i: %s", $stream->client_errnum, $stream->client_errmsg unless $stream->server_errcode || $stream->server_errmsg;
+			croak sprintf "%s:\n%s\nBolt error %i: %s", $stream->server_errcode, $stream->server_errmsg, $stream->client_errnum, $stream->client_errmsg;
+		}
 	}
 	else {
 		# simulate a JSON-backed result stream (only used in testing)
@@ -231,27 +238,27 @@ Neo4j::Driver::StatementResult - Result of running a Cypher statement (a stream
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
  use Neo4j::Driver;
- my $session = Neo4j::Driver->new->basic_auth(...)->session;
+ $session = Neo4j::Driver->new->basic_auth(...)->session;
  
  # stream result records
- my $result = $session->run('MATCH (a:Actor) RETURN a.name, a.born');
- while ( my $record = $result->fetch ) {
+ $result = $session->run('MATCH (a:Actor) RETURN a.name, a.born');
+ while ( $record = $result->fetch ) {
    ...
  }
  
  # list result records
- my $result = $session->run('MATCH (m:Movie) RETURN m.name, m.year');
- my $record_count = $result->size;
- my @records = $result->list;
+ $result = $session->run('MATCH (m:Movie) RETURN m.name, m.year');
+ $record_count = $result->size;
+ @records = $result->list;
  
  # shortcut for results with a single record only
- my $query = 'MATCH (m:Movie) WHERE id(m) = {id} RETURN m.name';
- my $name = $session->run($query, id => 12)->single->get('m.name');
+ $query = 'MATCH (m:Movie) WHERE id(m) = {id} RETURN m.name';
+ $name = $session->run($query, id => 12)->single->get('m.name');
 
 =head1 DESCRIPTION
 
@@ -282,7 +289,7 @@ L<Neo4j::Driver::StatementResult> implements the following methods.
 
 =head2 fetch
 
- while (my $record = $result->fetch) {
+ while ($record = $result->fetch) {
    ...
  }
 
@@ -295,7 +302,7 @@ exhausted and C<fetch()> returns C<undef>.
 
 =head2 has_next
 
- while (my $record = $result->fetch) {
+ while ($record = $result->fetch) {
    print $record->get('field');
    print ', ' if $result->has_next;
  }
@@ -307,14 +314,14 @@ detach the result, but will never exhaust it.
 
 =head2 keys
 
- my @keys = $result->keys;
+ @keys = $result->keys;
 
 Retrieve the column names of the records this result contains.
 
 =head2 list
 
- my @records = $result->list;
- my $records = $result->list;  # arrayref
+ @records = $result->list;
+ $records = $result->list;  # arrayref
 
 Return the entire list of all L<Record|Neo4j::Driver::Record>s that
 remain in the result stream. Calling this method exhausts the result
@@ -327,7 +334,7 @@ This method returns an array reference if called in scalar context.
 
 =head2 single
 
- my $name = $session->run('... LIMIT 1')->single->get('name');
+ $name = $session->run('... LIMIT 1')->single->get('name');
 
 Return the single L<Record|Neo4j::Driver::Record> left in the result
 stream, failing if there is not exactly one record left. Calling this
@@ -338,7 +345,7 @@ method multiple times returns the buffered record.
 
 =head2 size
 
- my $record_count = $result->size;
+ $record_count = $result->size;
 
 Return the count of records that calling C<list()> would yield.
 
@@ -347,7 +354,7 @@ for use by C<list()>.
 
 =head2 summary
 
- my $result_summary = $result->summary;
+ $result_summary = $result->summary;
 
 Return a L<Neo4j::Driver::ResultSummary> object. Calling this method
 detaches the result stream, but does I<not> exhaust it.
@@ -356,8 +363,8 @@ As a special case, L<Record|Neo4j::Driver::Record>s returned by the
 C<single> method also have a C<summary> method that works the same
 way.
 
- my $record = $transaction->run('...')->single;
- my $result_summary = $record->summary;
+ $record = $transaction->run('...')->single;
+ $result_summary = $record->summary;
 
 =head1 EXPERIMENTAL FEATURES
 
@@ -368,15 +375,15 @@ depend upon these features.
 
 =head2 Calling in scalar context
 
- my $keys = $result->keys;  # arrayref
+ $keys = $result->keys;  # arrayref
 
 The C<keys()> method returns an array reference if called in scalar
 context.
 
 =head2 Control result stream attachment
 
- my $buffered = $result->attached;  # boolean
- my $count = $result->detach;  # number of records fetched
+ $buffered = $result->attached;  # boolean
+ $count = $result->detach;  # number of records fetched
 
 If necessary, C<detach()> can force the entire result stream to
 be buffered locally, so that it will be available to C<fetch()>
@@ -400,7 +407,7 @@ exhausts the result stream.
 
 As a side effect, discarding the result yields a summary of it.
 
- my $result_summary = $result->consume;
+ $result_summary = $result->consume;
 
 All of the official drivers offer this method, but it doesn't appear
 to be necessary here, since L<Neo4j::Bolt::ResultStream> reliably
@@ -418,13 +425,20 @@ buffer and detach the result, but will never exhaust it.
 
 =head1 SEE ALSO
 
-L<Neo4j::Driver>,
-L<Neo4j::Driver::Record>,
-L<Neo4j::Driver::ResultSummary>,
-L<Neo4j Java Driver|https://neo4j.com/docs/api/java-driver/current/index.html?org/neo4j/driver/v1/StatementResult.html>,
-L<Neo4j Python Driver|https://neo4j.com/docs/api/python-driver/current/results.html>,
-L<Neo4j JavaScript Driver|https://neo4j.com/docs/api/javascript-driver/current/class/src/v1/result.js~Result.html>,
-L<Neo4j .NET Driver|https://neo4j.com/docs/api/dotnet-driver/current/html/1ddb9dbe-f40f-26a3-e6f0-7be417980044.htm>
+=over
+
+=item * L<Neo4j::Driver>
+
+=item * L<Neo4j::Driver::B<Record>>,
+L<Neo4j::Driver::B<ResultSummary>>
+
+=item * Equivalent documentation for the official Neo4j drivers:
+L<Result (Java)|https://neo4j.com/docs/api/java-driver/current/index.html?org/neo4j/driver/Result.html>,
+L<Results (Python)|https://neo4j.com/docs/api/python-driver/current/results.html>,
+L<Result (JavaScript)|https://neo4j.com/docs/api/javascript-driver/current/class/src/result.js~Result.html>,
+L<IResult (.NET)|https://neo4j.com/docs/api/dotnet-driver/4.0/html/f1ac31ec-c6dd-798b-b5d6-3ca0794d7502.htm>
+
+=back
 
 =head1 AUTHOR
 
@@ -432,7 +446,7 @@ Arne Johannessen <ajnn@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016-2019 by Arne Johannessen.
+This software is Copyright (c) 2016-2020 by Arne Johannessen.
 
 This is free software, licensed under:
 
