@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::Type::Node;
 # ABSTRACT: Describes a node from a Neo4j graph
-$Neo4j::Driver::Type::Node::VERSION = '0.14';
+$Neo4j::Driver::Type::Node::VERSION = '0.15';
 
 use Carp qw(croak);
 
@@ -62,12 +62,12 @@ Neo4j::Driver::Type::Node - Describes a node from a Neo4j graph
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
- my $query = 'MATCH (m:Movie) RETURN m LIMIT 1';
- my $node = $driver->session->run($query)->single->get('m');
+ $query = 'MATCH (m:Movie) RETURN m LIMIT 1';
+ $node = $driver->session->run($query)->single->get('m');
  
  say 'Movie # ', $node->id(), ' :';
  say '   ', $node->get('name'), ' / ', $node->get('year');
@@ -96,14 +96,14 @@ L<Neo4j::Driver::Type::Node> implements the following methods.
 
 =head2 get
 
- my $value = $node->get('property_key');
+ $value = $node->get('property_key');
 
 Retrieve the value of this node's property with the given key.
 If no such key exists, return C<undef>.
 
 =head2 id
 
- my $id = $node->id;
+ $id = $node->id;
 
 Return a unique ID for this node.
 
@@ -117,14 +117,14 @@ Nodes and relationships do not share the same ID space.
 
 =head2 labels
 
- my @labels = $node->labels;
+ @labels = $node->labels;
 
 Return all labels of this node.
 
 =head2 properties
 
- my $hashref = $node->properties;
- my $value = $hashref->{property_key};
+ $hashref = $node->properties;
+ $value = $hashref->{property_key};
 
 Return all properties of this node as a hash reference.
 
@@ -137,13 +137,13 @@ these features.
 
 =head2 Calling in scalar context
 
- my $labels = $node->labels;  # fails
+ $labels = $node->labels;  # fails
 
 The C<labels()> method C<die>s if called in scalar context.
 
 =head2 Direct data structure access
 
- my $property_value = $node->{property_key};
+ $property_value = $node->{property_key};
 
 Currently, the node's properties may be directly accessed as
 if the node was a simple hashref. This is a concession to
@@ -155,7 +155,7 @@ Use the accessor methods C<get()> and C<properties()> instead.
 
 =head2 Deletion indicator
 
- my $node_exists = ! $node->deleted;
+ $node_exists = ! $node->deleted;
 
 In some circumstances, Cypher statements using C<DELETE> may still
 C<RETURN> nodes that were deleted. To help avoid confusion in
@@ -180,9 +180,15 @@ is returned instead.
 
 =head1 SEE ALSO
 
-L<Neo4j::Driver>,
-L<Neo4j Java Driver|https://neo4j.com/docs/api/java-driver/current/org/neo4j/driver/v1/types/Node.html>,
-L<Neo4j Python Driver|https://neo4j.com/docs/api/python-driver/current/types/graph.html#neo4j.types.graph.Node>
+=over
+
+=item * L<Neo4j::Driver>
+
+=item * Equivalent documentation for the official Neo4j drivers:
+L<Node (Java)|https://neo4j.com/docs/api/java-driver/current/index.html?org/neo4j/driver/types/Node.html>,
+L<Node (Python)|https://neo4j.com/docs/api/python-driver/current/types/graph.html#neo4j.types.graph.Node>
+
+=back
 
 =head1 AUTHOR
 
@@ -190,7 +196,7 @@ Arne Johannessen <ajnn@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016-2019 by Arne Johannessen.
+This software is Copyright (c) 2016-2020 by Arne Johannessen.
 
 This is free software, licensed under:
 
